# TLPDirectedDiscoveryFilter

Contains enum which represents code block type

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | [**TLPDirectedDiscoveryFilterEnum**](TLPDirectedDiscoveryFilterEnum.md) |  | 

## Example

```python
from openapi_client.models.tlp_directed_discovery_filter import TLPDirectedDiscoveryFilter

# TODO update the JSON string below
json = "{}"
# create an instance of TLPDirectedDiscoveryFilter from a JSON string
tlp_directed_discovery_filter_instance = TLPDirectedDiscoveryFilter.from_json(json)
# print the JSON string representation of the object
print TLPDirectedDiscoveryFilter.to_json()

# convert the object into a dict
tlp_directed_discovery_filter_dict = tlp_directed_discovery_filter_instance.to_dict()
# create an instance of TLPDirectedDiscoveryFilter from a dict
tlp_directed_discovery_filter_form_dict = tlp_directed_discovery_filter.from_dict(tlp_directed_discovery_filter_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


